Struct rlstats::RlStats [] [src]

pub struct RlStats { /* fields omitted */ }

A client for the RocketLeagueStats api.

Methods

impl RlStats
[src]

[src]

[src]

[src]

[src]

[src]

[src]

[src]

Searches rocketleaguestats' player database, not Rocket League's.

[src]

Retrieve more player data faster than you would otherwise be able to.

The max batch size is 10. Players that are not found will simply be excluded from the result.

[src]

[src]